All platforms.

datalog.parser


parseclj/s

(parse q)
(parse q opts)

Parses a query, given as a vector or a map, into a Query record.

Options:

:implicit-rules? a rule expression is allowed without a '%' binding in :in. Some engines pre-install rules, e.g. Datahike its bitemporal ones, so a query calling them never binds '%' itself. Either true, for any rule, or the collection of rule names that are pre-installed.

Parses a query, given as a vector or a map, into a Query record.

Options:

  :implicit-rules?  a rule expression is allowed without a '%' binding in
                    :in. Some engines pre-install rules, e.g. Datahike its
                    bitemporal ones, so a query calling them never binds '%'
                    itself. Either true, for any rule, or the collection of
                    rule names that are pre-installed.
sourceraw docstring

parse-rulesclj/s

(parse-rules rules)
source

cljdoc builds & hosts documentation for Clojure/Script libraries