(deftrecord tagname fields & rest)Augment all parser records with default implementation of ITraversable
Augment all parser records with default implementation of ITraversable
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |