datalog.unparser


PUnparseclj/sprotocol

-unparseclj/s

(-unparse this)
source

unparseclj/s

(unparse v)

Converts a parsed query record back into the query vector DSL. Inverse of datalog.parser/parse.

Converts a parsed query record back into the query vector DSL.
Inverse of datalog.parser/parse.
sourceraw docstring

unparse-rulesclj/s

(unparse-rules rules)

Converts a collection of parsed Rule records back into the rules vector DSL. Inverse of datalog.parser/parse-rules.

Converts a collection of parsed Rule records back into the rules vector DSL.
Inverse of datalog.parser/parse-rules.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries