(unparse v)Converts a parsed query record back into the query vector DSL. Inverse of datalog.parser/parse.
Converts a parsed query record back into the query vector DSL. Inverse of datalog.parser/parse.
(unparse-rules rules)Converts a collection of parsed Rule records back into the rules vector DSL. Inverse of datalog.parser/parse-rules.
Converts a collection of parsed Rule records back into the rules vector DSL. Inverse of datalog.parser/parse-rules.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |